import React from 'react';
import {StyleSheet, View, Button, Modal, Image} from 'react-native';
import Ziggeo from 'react-native-ziggeo-library';


const ZIGGEO_APP_TOKEN = 'ZIGGEO_APP_TOKEN';

export default class App extends React.Component {

  async recordVideo() {
    var appToken = ZIGGEO_APP_TOKEN;
    Ziggeo.setAppToken(appToken);
    Ziggeo.setCameraSwitchEnabled(true);
    Ziggeo.setCoverSelectorEnabled(false);
    Ziggeo.setCamera(Ziggeo.REAR_CAMERA);
    Ziggeo.setBlurMode(false);
    Ziggeo.setQuality(Ziggeo.HIGH_QUALITY);
    Ziggeo.setMaxRecordingDuration(600);
    var argsMap = { 
      expiration_days: 1,
      video_profile: '_video_profile_lightweight',
      auto_pad: true,
      data: '{"source":"app"}',
    };
    Ziggeo.setExtraArgsForRecorder(argsMap);

    var uploadConfig = {
      tags: 'record_test',
    };
    Ziggeo.setUploadingConfig(uploadConfig);
    try {
      var token = await Ziggeo.startCameraRecorder();
      console.log('Token:' + token);
      if (token) {
        Ziggeo.playVideo(token);
      }
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  async uploadFromFileSelector() {
    var appToken = ZIGGEO_APP_TOKEN;
    Ziggeo.setAppToken(appToken);

    var config = {
      effect_profile: 'r13491602fb6b2be662a8868ad621fb6,r11944fc2068b54c0d57cc9192a24017,r13491602fb6b2be662a8868ad688888',
    };
    Ziggeo.setUploadingConfig(config);

    try {
      var argsMap = {
        max_duration: 15,
        enforce_duration: true,
        tags: 'upload_test',
      };
      var token = await Ziggeo.uploadFromFileSelector(argsMap);
      console.log('Token:' + token);
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  async uploadFromPath() {
    var appToken = ZIGGEO_APP_TOKEN;
    Ziggeo.setAppToken(appToken);

    try {
      var filePath = 'File_Path';
      var argsMap = {
        max_duration: 15,
        enforce_duration: true,
        tags: 'TEST_TAG',
      };

      var token = await Ziggeo.uploadFromPath(filePath, argsMap);
      console.log('Token:' + token);
      if (token) {
        Ziggeo.playVideo(token);
      }
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  async playVideo() {
    var appToken = ZIGGEO_APP_TOKEN;
    var videoToken = 'Video_Token';
    Ziggeo.setAppToken(appToken);
    
    try {
      const videoUrl = await Ziggeo.VideosApi.getVideoUrl(videoToken);
      console.log('videoUrl : ', videoUrl);
    
      var map = {
        hidePlayerControls: 'false',
      };
      Ziggeo.setThemeArgsForPlayer(map);
      Ziggeo.playVideo(videoToken);
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  async recordAudio() {
    var appToken = ZIGGEO_APP_TOKEN;
    Ziggeo.setAppToken(appToken);
    Ziggeo.setBlurring

    var uploadConfig = {
      tags: 'record_audio_test',
    };
    Ziggeo.setUploadingConfig(uploadConfig);

    try {
      Ziggeo.startAudioRecorder();
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  async playAudio() {
    var appToken = ZIGGEO_APP_TOKEN;
    var audioToken = 'Audio_Token';
    
    Ziggeo.setAppToken(appToken);
    try {
      Ziggeo.startAudioPlayer(audioToken);
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  async startImageRecorder() {
    var appToken = ZIGGEO_APP_TOKEN;
    Ziggeo.setAppToken(appToken);
    try {
      Ziggeo.startImageRecorder();
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  async showImage() {
    var appToken = ZIGGEO_APP_TOKEN;
    Ziggeo.setAppToken(appToken);
    let imageToken = "Image_Token";
    try {
      Ziggeo.showImage(imageToken);
    } catch (e) {
      console.log('Error:' + e);
      alert(e);
    }
  }

  subscribeForEvents(): string {
    const recorderEmitter = Ziggeo.recorderEmitter();
    recorderEmitter.addListener('CancelledByUser', data =>
      console.log('CancelledByUser:' + data),
    );
    recorderEmitter.addListener('Error', data =>
      console.log('Error:'),
    );

    recorderEmitter.addListener('ManuallySubmitted', data =>
      console.log('ManuallySubmitted:'),
    );
    recorderEmitter.addListener('RecordingStarted', data =>
      console.log('RecordingStarted:'),
    );
    recorderEmitter.addListener('RecordingStopped', data =>
      console.log('RecordingStopped:' + data.path),
    );
    recorderEmitter.addListener('Countdown', data =>
      console.log('Countdown:'),
    );
    recorderEmitter.addListener('RecordingProgress', data =>
      console.log('RecordingProgress:' + data.millis_passed),
    );
    recorderEmitter.addListener('ReadyToRecord', data =>
      console.log('ReadyToRecord:'),
    );
    recorderEmitter.addListener('Rerecord', data =>
      console.log('Rerecord:'),
    );

    recorderEmitter.addListener('StreamingStarted', data =>
      console.log('StreamingStarted:'),
    );
    recorderEmitter.addListener('StreamingStopped', data =>
      console.log('StreamingStopped:'),
    );

    recorderEmitter.addListener('NoCamera', data =>
      console.log('NoCamera:'),
    );
    recorderEmitter.addListener('HasCamera', data =>
      console.log('HasCamera:'),
    );
    recorderEmitter.addListener('MicrophoneHealth', data =>
      console.log('MicrophoneHealth:'),
    );
    recorderEmitter.addListener('NoMicrophone', data =>
      console.log('NoMicrophone:'),
    );
    recorderEmitter.addListener('HasMicrophone', data =>
      console.log('HasMicrophone:'),
    );
    recorderEmitter.addListener('AccessGranted', data =>
      console.log('AccessGranted:', data),
    );
    recorderEmitter.addListener('AccessForbidden', data =>
      console.log('AccessForbidden:', data),
    );

    recorderEmitter.addListener('UploadingStarted', data =>
      console.log('UploadingStarted:', data),
    );
    recorderEmitter.addListener('UploadProgress', data =>
      console.log('UploadProgress:', data),
    );
    recorderEmitter.addListener('Verified', data =>
      console.log('Verified:', data),
    );
    recorderEmitter.addListener('Processing', data =>
      console.log('Processing:', data),
    );
    recorderEmitter.addListener('Processed', data =>
      console.log('Processed:', data),
    );
    recorderEmitter.addListener('Uploaded', data =>
      console.log('Uploaded:', data),
    );

    recorderEmitter.addListener('UploadSelected', data =>
      console.log('UploadSelected:'),
    );

    recorderEmitter.addListener('Playing', data =>
      console.log('Playing:'),
    );
    recorderEmitter.addListener('Paused', data =>
      console.log('Paused:'),
    );
    recorderEmitter.addListener('Ended', data =>
      console.log('Ended:'),
    );
    recorderEmitter.addListener('Seek', data =>
      console.log('Seek:'),
    );
    recorderEmitter.addListener('ReadyToPlay', data =>
      console.log('ReadyToPlay:'),
    );

    return '';
  }

  

  render() {
    this.subscribeForEvents();

    return (
      <View style={{flex: 1, backgroundColor: '#fff', width: '100%', height: '100%'}}>
        <View style={styles.container}>
          <Button
            onPress={this.recordVideo}
            title="Record Video"
            accessibilityLabel="Record Video"
          />
          <Button
            onPress={this.uploadFromFileSelector}
            title="Upload from library"
            accessibilityLabel="Upload from library"
          />
          <Button
            onPress={this.uploadFromPath}
            title="Upload From Path"
            accessibilityLabel="Upload From Path"
          />
          <Button
            onPress={this.playVideo}
            title="Play Video"
            accessibilityLabel="Play Video"
          />
          <Button
            onPress={this.recordAudio}
            title="Record Audio"
            accessibilityLabel="Record Audio"
          />
          <Button
            onPress={this.playAudio}
            title="Play Audio"
            accessibilityLabel="Play Audio"
          />
          <Button
            onPress={this.startImageRecorder}
            title="Take Photo"
            accessibilityLabel="Take Photo"
          />
          <Button
            onPress={this.showImage}
            title="Show Image"
            accessibilityLabel="Show Image"
          />
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#fff',
    alignItems: 'center',
    justifyContent: 'center',
  },
});